Name: gretl	
Version: 2017b
Release: 1%{?dist}
Summary: A tool for econometric analysis	

Group: Applications/Engineering
License: GPLv3+ and BSD and MIT
URL: http://gretl.sourceforge.net/
Source0: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz
#Licensing of plugins used in gretl
Source1: gretl_plugins.txt

BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

BuildRequires:  bash-completion
BuildRequires:	blas-devel
BuildRequires:	desktop-file-utils
BuildRequires:	fftw-devel
BuildRequires:	gettext
BuildRequires:	glib2-devel
BuildRequires:	gmp-devel
BuildRequires:	gnuplot
BuildRequires:	gtk3-devel
BuildRequires:	gtksourceview3-devel
BuildRequires:	json-glib-devel
BuildRequires:	lapack-devel
BuildRequires:	libcurl-devel
BuildRequires:	libxml2-devel
BuildRequires:	libgnomeui-devel
BuildRequires:	mpfr-devel
BuildRequires:	ncurses-devel
BuildRequires:	openmpi-devel
BuildRequires:	readline-devel
BuildRequires:	xdg-utils

Requires: gnuplot
Requires: gtksourceview3
Requires: libcurl

%description
A cross-platform software package for econometric analysis, 
written in the C programming language.

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package contains the development files for %{name}.

%package openmpi
Summary: Binary openmpi files for %{name}
BuildRequires: openmpi-devel
# Require explicitly for dir ownership and to guarantee the pickup of the right runtime
Requires: openmpi
Requires: %{name} = %{version}-%{release}

%description openmpi
This package contains the binary openmpi files for %{name}.

%prep
%setup -q

CC=mpicc
CXX=mpic++
FC=mpifort

%build
# Build OpenMPI version
%{_openmpi_load}
%configure 	--disable-static \
		--disable-avx \
        --with-mpi \
        --with-mpi-lib=%{_libdir}/openmpi/lib/ \
        --with-mpi-include=%{_includedir}/openmpi-%_arch/
make %{?_smp_mflags}
cp %{SOURCE1} %{_builddir}/%{name}-%{version}/gretl_plugins.txt



%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
%find_lang %{name}
rm -rf %{buildroot}/%{_libdir}/libgretl*.la
rm -rf %{buildroot}/%{_libdir}/gretl-gtk2/*.la
rm -rf %{buildroot}/%{_datadir}/%{name}/doc

#Fix the openmpi binary
mkdir -p %{buildroot}%{_libdir}/openmpi/bin
mv %{buildroot}/%{_bindir}/gretlmpi %{buildroot}/%{_libdir}/openmpi/bin/gretl_openmpi

desktop-file-install						\
--remove-category="Application;Science;Econometrics" \
--add-category="Education;Science;Math;Economy;"  \
--dir=%{buildroot}%{_datadir}/applications     \
%{buildroot}/%{_datadir}/applications/gretl.desktop
%{_openmpi_unload}
%post 
/sbin/ldconfig
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/bin/touch --no-create %{_datadir}/mime/packages &> /dev/null || :

%postun 
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    /bin/touch --no-create %{_datadir}/mime/packages &> /dev/null || :
    /usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :



%clean
rm -rf %{buildroot}


%files -f %{name}.lang
%defattr(-,root,root,-)
%{_bindir}/gretl
%{_bindir}/gretlcli
%{_bindir}/gretl_x11
%{_libdir}/gretl-gtk3
%{_datadir}/%{name}/
%{_mandir}/man1/*.gz
%{_libdir}/libgretl-1.0.so.*
%{_datadir}/mime/packages/gretl.xml
%{_datadir}/gtksourceview-3.0/language-specs/*.lang
%{_datadir}/icons/hicolor/32x32/apps/gretl.png
%{_datadir}/icons/hicolor/32x32/mimetypes/*.png
%{_datadir}/icons/hicolor/48x48/apps/gretl.png
%{_datadir}/icons/hicolor/64x64/apps/gretl.png
%{_datadir}/applications/gretl*
%{_datadir}/appdata/gretl.appdata.xml
%{_datadir}/bash-completion/completions/%{name}cli

%doc ChangeLog CompatLog README.audio README gretl_plugins.txt

%files devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/gretl.pc
%{_libdir}/libgretl*.so
%{_includedir}/%{name}/

%files openmpi 
%{_libdir}/openmpi/bin/gretl_openmpi

%changelog
* Sat May 27 2017 Johannes Lips <hannes@fedoraproject.org> - 2017b-1
- Update to 2017b

* Sun Apr 16 2017 Johannes Lips <hannes@fedoraproject.org> - 2017a-1
- Update to 2017a

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2016d-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Jan 30 2017 Johannes Lips <hannes@fedoraproject.org> - 2016d-4
- rebuild for gcc 

* Thu Jan 12 2017 Igor Gnatenko <ignatenko@redhat.com> - 2016d-3
- Rebuild for readline 7.x

* Tue Nov 29 2016 Johannes Lips <hannes@fedoraproject.org> - 2016d-2
- additional changes fixing the openmpi parts

* Sat Nov 26 2016 Johannes Lips <hannes@fedoraproject.org> - 2016d-1
- Update to 2016d
- openmpi subpackage 

* Thu Jul 07 2016 Johannes Lips <hannes@fedoraproject.org> - 2016c-1
- Update to 2016c

* Fri Apr 15 2016 Johannes Lips <hannes@fedoraproject.org> - 2016b-1
- Update to 2016b

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2016a-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 30 2016 Johannes Lips <hannes@fedoraproject.org> - 2016a-1
- Update to 2016a

* Wed Oct 21 2015 Johannes Lips <hannes@fedoraproject.org> - 2015d-1
- Update to 2015d
- move to a new versioning scheme

* Thu Sep 17 2015 Johannes Lips <hannes@fedoraproject.org> - 1.10.2-1
- Update to 1.10.2

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.10.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Apr 23 2015 Johannes Lips <hannes@fedoraproject.org> - 1.10.1-2
- disable the AVX switch to fix bug #1213980

* Sat Apr 04 2015 Johannes Lips <hannes@fedoraproject.org> - 1.10.1-1
- Update to 1.10.1

* Fri Apr 03 2015 Johannes Lips <hannes@fedoraproject.org> - 1.10.0-1
- Update to 1.10.0
